@@ -41,3 +41,15 @@ class APIKeyError(APIError):
     status_code = 403
     detail = 'api key not valid'
     code = 'api_key_error'
+
+
+class SerializerError(APIError):
+    status_code = 403
+    detail = 'serializer not valid'
+    code = 'serializer_error'
+
+
+class RegisterDecodeTypeError(APIError):
+    status_code = 403
+    detail = 'token typ not valid'
+    code = 'register_decode_type_error'
