@@ -4,6 +4,7 @@ from django.conf import settings
 from revauth.settings import api_settings
 import requests
 import json
+from revauth import exceptions
 
 
 class BaseCryptor:
@@ -29,10 +30,22 @@ class BaseCryptor:
 
 
 class JWTCryptor(BaseCryptor):
+    def __init__(self, headers=None, unverified=None):
+        if not headers or not unverified:
+            return
+        iss, version = unverified['iss'].split('/')
+        if version not in ['v2', 'v1']:
+            kid = headers['kid']
+            certs = f'https://{unverified["iss"]}/certs'
+            keys = requests.get(certs).json()['keys']
+            key = [k for k in keys if k['kid'] == kid][0]
+            key = JWK.from_json(json.dumps(key))
+            self.pub_key = key.export_to_pem()
+
     def decode_register(self, token):
         decoded = self.decode(token)
         if decoded['typ'] != 'register':
-            raise
+            raise exceptions.RegisterDecodeTypeError
         return decoded
 
     def encode(self, data):
