@@ -11,7 +11,7 @@ class RegisterSerializer(serializers.Serializer):
     access_token = serializers.CharField()
 
 
-class ProfileJWTSerializer(serializers.Serializer):
+class ProfileJWTSerializer(serializers.ModelSerializer):
     groups = serializers.SerializerMethodField()
     id = serializers.CharField()
 
@@ -27,3 +27,8 @@ class ProfileJWTSerializer(serializers.Serializer):
 
 class SocialSerializer(serializers.Serializer):
     token = serializers.CharField()
+
+
+class LoginSerializer(serializers.Serializer):
+    identity = serializers.CharField()
+    password = serializers.CharField()
